pub struct DrawImage { /* private fields */ }
The draw:image element represents an image. An image can be either: • A link to an external resource or • Embedded in the document The draw:image element may have text content. Text content is displayed in addition to the image data. Note: While the image data may have an arbitrary format, vector graphics should be stored in the [SVG] format and bitmap graphics in the [PNG] format.

Implementations

source

impl DrawImage

source

pub fn new() -> Self

New.

source

pub fn attrmap(&self) -> &AttrMap2

Allows access to all attributes of the style itself.

source

pub fn attrmap_mut(&mut self) -> &mut AttrMap2

Allows access to all attributes of the style itself.

source

pub fn get_binary_base64(&self) -> Option<&String>

Image binary data.

source

pub fn set_binary_base64(&mut self, binary: String)

Image binary data.

source

pub fn get_binary(&self) -> Result<Vec<u8>, OdsError>

Image binary data.

source

pub fn set_binary(&mut self, binary: &[u8])

Image binary data. Note: While the image data may have an arbitrary format, vector graphics should be stored in the [SVG] format and bitmap graphics in the [PNG] format.

source

pub fn clear_binary(&mut self)

Image binary data.

source

pub fn get_text(&self) -> &Vec<TextTag>

Text

source

pub fn push_text(&mut self, text: TextTag)

Text

source

pub fn push_text_str<S: Into<String>>(&mut self, text: S)

Text

source

pub fn set_text(&mut self, text: Vec<TextTag>)

Text

source

pub fn set_draw_filter_name<S: Into<String>>(&mut self, name: S)

The draw:filter-name attribute specifies the implementation-dependent filter name that has been used to load an image into the document

source

pub fn set_draw_mime_type<S: Into<String>>(&mut self, name: S)

The draw:mime-type attribute specifies the MIME type of the media type that a plugin processes, or the MIME type of the image given by a draw:image element. Valid values for this attribute are those defined in accordance with 3.7 of [RFC2616], or registered in accordance with [RFC6838]. Note: Additional information on MIME media types can be found at [MIMETYPES].

See 5.6.2 of [XLink].

The xlink:href 19.916 attribute specifies a remote resource. Its data type is anyIRI. See 5.4 of [XLink].

See 5.6.1 of [XLink].

See 3.2 of [XLink]. This attribute always has the value ‘simple’ in OpenDocument document instances.

source

pub fn set_xml_id<S: Into<String>>(&mut self, id: S)

The table:end-y attribute specifies the y-coordinate of the end position of a shape relative to the top-left edge of a cell. The size attributes of the shape are ignored.