Enum spreadsheet_ods::SplitMode
source · pub enum SplitMode {
None = 0,
Split = 1,
Heading = 2,
}Expand description
There are two ways a sheet can be split. There are fixed column/row header like splits, and there is a moveable split.
Variants