Struct spreadsheet_ods::metadata::MetaAutoReload
source · pub struct MetaAutoReload {
pub delay: Option<Duration>,
pub actuate: Option<XLinkActuate>,
pub href: Option<String>,
pub show: Option<XLinkShow>,
pub link_type: Option<XLinkType>,
}Expand description
Specifies whether a document is reloaded or replaced by another document after a specified period of time has elapsed.
Fields
delay: Option<Duration>The meta:delay attribute specifies a reload delay.
actuate: Option<XLinkActuate>See XLink
href: Option<String>See XLink
show: Option<XLinkShow>See XLink
link_type: Option<XLinkType>See XLink
Implementations