Struct spreadsheet_ods::metadata::MetaTemplate
source · pub struct MetaTemplate {
pub date: Option<NaiveDateTime>,
pub actuate: Option<XLinkActuate>,
pub href: Option<String>,
pub title: Option<String>,
pub link_type: Option<XLinkType>,
}Expand description
Specifies an IRI for the document template that was used to create a document.
Fields
date: Option<NaiveDateTime>The meta:date attribute specifies the date and time when a template was last modified, prior to being used to create the current document.
actuate: Option<XLinkActuate>See XLink
href: Option<String>See XLink
title: Option<String>See XLink
link_type: Option<XLinkType>See XLink
Implementations