Struct spreadsheet_ods::OdsOptions
source · pub struct OdsOptions { /* private fields */ }Expand description
Read options for ods-files.
Implementations
sourceimpl OdsOptions
impl OdsOptions
sourcepub fn content_only(self) -> Self
pub fn content_only(self) -> Self
Parse the content only. Doesn’t buffer any extra files and ignores styles etc. Shaves off some time and memory if only the data is required.
sourcepub fn use_repeat_for_cells(self) -> Self
pub fn use_repeat_for_cells(self) -> Self
Cells are duplicated based on their table:number-columns-repeated. With this switch the behaviour is turned off, and the repeat-count is stored with each cell.
sourcepub fn use_repeat_for_empty(self) -> Self
pub fn use_repeat_for_empty(self) -> Self
Cells are duplicated based on their table:number-columns-repeated. With this switch this duplications is turned off for cells with no value and no formula. Instead these cells are stored with a repeat-count.
sourcepub fn use_clone_for_repeat(self) -> Self
pub fn use_clone_for_repeat(self) -> Self
Cells are always duplicated based on their table:number-columns-repeated. Warning: This can blow up read times significantly.