HeaderFooter

Struct HeaderFooter 

pub struct HeaderFooter { /* private fields */ }
Header/Footer data. Can be seen as three regions left/center/right or as one region. In the first case region* contains the data, in the second it’s content. Each is a TextTag of parsed XML-tags.

Implementations

Source

impl HeaderFooter

pub fn new() -> Self

Create

pub fn set_display(&mut self, display: bool)

Is the header displayed. Used to deactivate left side headers.

pub fn display(&self) -> bool

Display

pub fn is_empty(&self) -> bool

true if all regions of the header/footer are empty.

pub fn set_left(&mut self, txt: Vec<TextTag>)

Set the content of the left region of the header.

Attention: This tag must be a text:p otherwise its ignored.

pub fn add_left(&mut self, txt: TextTag)

Adds to the content of the left region of the header.

Attention: This tag must be a text:p otherwise its ignored.

pub fn clear_left(&mut self)

Clear left region.

pub fn left(&self) -> &Vec<TextTag>

Left region.

pub fn left_mut(&mut self) -> &mut Vec<TextTag>

Left region.

pub fn set_center(&mut self, txt: Vec<TextTag>)

Set the content of the center region of the header.

Attention: This tag must be a text:p otherwise its ignored.

pub fn add_center(&mut self, txt: TextTag)

Adds to the content of the center region of the header.

Attention: This tag must be a text:p otherwise its ignored.

pub fn clear_center(&mut self)

Center region.

pub fn center(&self) -> &Vec<TextTag>

Center region.

pub fn center_mut(&mut self) -> &mut Vec<TextTag>

Center region.

pub fn set_right(&mut self, txt: Vec<TextTag>)

Set the content of the right region of the header.

Attention: This tag must be a text:p otherwise its ignored.

pub fn add_right(&mut self, txt: TextTag)

Adds to the content of the right region of the header.

Attention: This tag must be a text:p otherwise its ignored.

pub fn clear_right(&mut self)

Right region.

pub fn right(&self) -> &Vec<TextTag>

Right region.

pub fn right_mut(&mut self) -> &mut Vec<TextTag>

Right region.

pub fn set_content(&mut self, txt: Vec<TextTag>)

Header content, if there are no regions.

pub fn add_content(&mut self, txt: TextTag)

Adds header content, if there are no regions.

pub fn content(&self) -> &Vec<TextTag>

Header content, if there are no regions.

pub fn content_mut(&mut self) -> &mut Vec<TextTag>

Header content, if there are no regions.