MasterPage

Struct MasterPage 

pub struct MasterPage { /* private fields */ }
Defines the structure and content for a page. Refers to a PageStyle for layout information. It must be attached to a Sheet to be used.

use spreadsheet_ods::{pt, Length, WorkBook, Sheet};
use spreadsheet_ods::style::{PageStyle, MasterPage, TableStyle};
use spreadsheet_ods::style::units::Border;
use spreadsheet_ods::xmltree::XmlVec;
use spreadsheet_ods::color::Rgb;
use icu_locale_core::locale;

let mut wb = WorkBook::new(locale!("en-US"));

let mut ps = PageStyle::new("ps1");
ps.set_border(pt!(0.5), Border::Groove, Rgb::new(128,128,128));
ps.headerstyle_mut().set_background_color(Rgb::new(92,92,92));
let ps_ref = wb.add_pagestyle(ps);

let mut mp1 = MasterPage::new("mp1");
mp1.set_pagestyle(&ps_ref);
mp1.header_mut().center_mut().add_text("center");
mp1.footer_mut().right_mut().add_text("right");
let mp1_ref = wb.add_masterpage(mp1);

let mut ts = TableStyle::new("ts1");
ts.set_master_page(&mp1_ref);
let ts_ref = wb.add_tablestyle(ts);

let mut sheet = Sheet::new("sheet 1");
sheet.set_style(&ts_ref);

Implementations

Source

impl MasterPage

pub fn new_empty() -> Self

Empty.

pub fn new<S: AsRef<str>>(name: S) -> Self

New MasterPage

pub fn masterpage_ref(&self) -> MasterPageRef

Style reference.

pub fn set_name(&mut self, name: String)

Name.

pub fn name(&self) -> &String

Name.

pub fn set_display_name(&mut self, display_name: String)

Name.

pub fn display_name(&self) -> &String

Name.

pub fn set_pagestyle(&mut self, name: &PageStyleRef)

Reference to a page-style.

pub fn pagestyle(&self) -> Option<&PageStyleRef>

Reference to a page-style.

pub fn set_next_masterpage(&mut self, master: &MasterPageRef)

The style:next-style-name attribute specifies the name of the master page that is used for the next page if the current page is entirely filled. If the next style name is not specified, the current master page is used for the next page. The value of this attribute shall be the name of a style:master-page element.

pub fn next_masterpage(&self) -> Option<&MasterPageRef>

Next.

pub fn set_header(&mut self, header: HeaderFooter)

Left side header.

pub fn header(&self) -> &HeaderFooter

Left side header.

pub fn header_mut(&mut self) -> &mut HeaderFooter

Header.

pub fn set_header_first(&mut self, header: HeaderFooter)

First page header.

pub fn header_first(&self) -> &HeaderFooter

First page header.

pub fn header_first_mut(&mut self) -> &mut HeaderFooter

First page header.

pub fn set_header_left(&mut self, header: HeaderFooter)

Left side header.

pub fn header_left(&self) -> &HeaderFooter

Left side header.

pub fn header_left_mut(&mut self) -> &mut HeaderFooter

Left side header.

Footer.

pub fn footer(&self) -> &HeaderFooter

Footer.

pub fn footer_mut(&mut self) -> &mut HeaderFooter

Footer.

First page footer.

pub fn footer_first(&self) -> &HeaderFooter

First page footer.

pub fn footer_first_mut(&mut self) -> &mut HeaderFooter

First page footer.

Left side footer.

pub fn footer_left(&self) -> &HeaderFooter

Left side footer.

pub fn footer_left_mut(&mut self) -> &mut HeaderFooter

Left side footer.