LineWidth

Enum LineWidth 

pub enum LineWidth {
    Auto,
    Bold,
    Percent(Percent),
    Int(u32),
    Length(Length),
    Normal,
    Dash,
    Thin,
    Medium,
    Thick,
}
Line width for underline, overline, line-through.

20.377 style:text-line-through-width 20.383 style:text-overline-width 20.392 style:text-underline-width

The style:text-line-through-width attribute specifies the width of a line-through line. The value bold specifies a line width that is calculated from the font sizes like an auto width, but is wider than an auto width.

The defined values for the style:text-line-through-width attribute are:

  • auto: the width of a line-through should be calculated from the font size of the text where the line-through will appear.
  • bold: the width of a line-through should be calculated from the font size of the text where the line-through will appear but is wider than for the value of auto.
  • a value of type percent 18.3.23
  • a value of type positiveInteger 18.2
  • a value of type positiveLength 18.3.26

The line-through text styles referenced by the values dash, medium, thick and thin, are implementation-defined. Thin shall be smaller width than medium and medium shall be a smaller width than thick.

The values of the style:text-line-through-width attribute are auto, normal, bold, thin, medium, thick, a value of type positiveInteger 18.2, a value of type percent 18.3.23 or a value of type positiveLength 18.3.26.

Variants



Auto



Bold



Percent(Percent)



Int(u32)



Length(Length)



Normal



Dash



Thin



Medium



Thick