pub enum MasterPageUsage {
All,
Left,
Mirrored,
Right,
}Expand description
19.509 style:page-usage
The style:page-usage attribute specifies the type of pages that a master page should generate.
The defined values for the style:page-usage attribute are:
- all: if there are no style:header-left or style:footer-left elements, the header and footer content is the same for left and right pages.
- left: style:header-right and style:footer-right elements are ignored.
- mirrored: if there are no style:header-left or style:footer-left elements, the header and footer content is the same for left and right pages.
- right: style:header-left and style:footer-left elements are ignored.
The default value for this attribute is all.
Variants