PrintCentering

Enum PrintCentering 

pub enum PrintCentering {
    None,
    Horizontal,
    Vertical,
    Both,
}
20.363 style:table-centering

The style:table-centering attribute specifies whether tables are centered horizontally and/ or vertically on the page. This attribute only applies to spreadsheet documents.

The default is to align the table to the top-left or top-right corner of the page, depending of its writing direction.

The defined values for the style:table-centering attribute are:

  • both: tables should be centered both horizontally and vertically on the pages where they appear.
  • horizontal: tables should be centered horizontally on the pages where they appear.
  • none: tables should not be centered both horizontally or vertically on the pages where they appear.
  • vertical: tables should be centered vertically on the pages where they appear.

Variants



None



Horizontal



Vertical



Both