pub enum PrintContent {
Headers,
Grid,
Annotations,
Objects,
Charts,
Drawings,
Formulas,
ZeroValues,
}Expand description
20.330 style:print
The style:print attribute specifies the components in a spreadsheet document to print.
The value of the style:print attribute is a white space separated list of one or more of these values:
- annotations: annotations should be printed.
- charts: charts should be printed.
- drawings: drawings should be printed.
- formulas: formulas should be printed.
- grid: grid lines should be printed.
- headers: headers should be printed.
- objects: (including graphics): objects should be printed.
- zero-values: zero-values should be printed.
Variants