pub enum RelativeScale {
Scale,
ScaleMin,
Percent(Percent),
}Expand description
20.340 style:rel-width
The style:rel-width attribute specifies the width of a table relative to the width of the area that the table is in.
The style:rel-width attribute has the data type percent 18.3.23.
Variants