pub enum TabStopType {
Center,
Left,
Right,
Char,
}Expand description
19.519 style:type
The style:type attribute specifies the type of a tab stop within paragraph formatting properties.
The defined values for the style:type attribute are:
- center: text is centered on a tab stop.
- char: character appears at a tab stop position.
- left: text is left aligned with a tab stop.
- right: text is right aligned with a tab stop.
For a style:tab-stop 17.8 element the default value for this attribute is left.
Variants