TableAlign

Enum TableAlign 

pub enum TableAlign {
    Center,
    Left,
    Right,
    Margins,
}
20.414 table:align

The table:align attribute specifies the horizontal alignment of a table.

The defined values for the table:align attribute are:

  • center: table aligns to the center between left and right margins.
  • left: table aligns to the left margin.
  • margins: table fills all the space between the left and right margins.
  • right: table aligns to the right margin.

Consumers that do not support the margins value, may treat this value as left.

Variants



Center



Left



Right



Margins