pub enum TextAlign {
    Start,
    Center,
    End,
    Justify,
    Inside,
    Outside,
    Left,
    Right,
}
20.223 fo:text-align

See 7.15.9 of XSL.

If there are no values specified for the fo:text-align and style:justify-single-word 20.301 attributes within the same formatting properties element, the values of those attributes is set to start and false respectively. In the OpenDocument XSL-compatible namespace, the fo:text-align attribute does not support the inherit, inside, outside, or string values.

The values of the fo:text-align attribute are start, end, left, right, center or justify.

Variants



Start



Center



End



Justify



Inside



Outside



Left



Right