pub enum TextAutoSpace {
    IdeographAlpha,
    None,
}
20.365 style:text-autospace

The style:text-autospace attribute specifies whether to add space between portions of Asian, Western, and complex texts.

The defined values for the style:text-autospace attribute are: • ideograph-alpha: space should be added between portions of Asian, Western and Complex texts. • none: space should not be added between portions of Asian, Western and complex texts.

Variants



IdeographAlpha



None