pub struct TextA { /* private fields */ }Expand description
$literal
Implementations
Sourceimpl TextA
impl TextA
Sourcepub fn style_name(self, style: &TextStyleRef) -> Self
pub fn style_name(self, style: &TextStyleRef) -> Self
The text:style-name attribute specifies a text style for an unvisited hyperlink.
Sourcepub fn visited_style_name(self, style: &TextStyleRef) -> Self
pub fn visited_style_name(self, style: &TextStyleRef) -> Self
The text:visited-style-name attribute specifies a style for a hyperlink that has been visited.