Struct spreadsheet_ods::draw::DrawImage
source · pub struct DrawImage { /* private fields */ }Expand description
The draw:image element represents an image. An image can be either: • A link to an external resource or • Embedded in the document The draw:image element may have text content. Text content is displayed in addition to the image data. Note: While the image data may have an arbitrary format, vector graphics should be stored in the [SVG] format and bitmap graphics in the [PNG] format.
Implementations
sourceimpl DrawImage
impl DrawImage
sourcepub fn attrmap_mut(&mut self) -> &mut AttrMap2
pub fn attrmap_mut(&mut self) -> &mut AttrMap2
Allows access to all attributes of the style itself.
sourcepub fn get_binary_base64(&self) -> Option<&String>
pub fn get_binary_base64(&self) -> Option<&String>
Image binary data.
sourcepub fn set_binary_base64(&mut self, binary: String)
pub fn set_binary_base64(&mut self, binary: String)
Image binary data.
sourcepub fn set_binary(&mut self, binary: &[u8])
pub fn set_binary(&mut self, binary: &[u8])
Image binary data. Note: While the image data may have an arbitrary format, vector graphics should be stored in the [SVG] format and bitmap graphics in the [PNG] format.
sourcepub fn clear_binary(&mut self)
pub fn clear_binary(&mut self)
Image binary data.
sourcepub fn push_text_str<S: Into<String>>(&mut self, text: S)
pub fn push_text_str<S: Into<String>>(&mut self, text: S)
Text
sourcepub fn set_draw_filter_name<S: Into<String>>(&mut self, name: S)
pub fn set_draw_filter_name<S: Into<String>>(&mut self, name: S)
The draw:filter-name attribute specifies the implementation-dependent filter name that has been used to load an image into the document
sourcepub fn set_draw_mime_type<S: Into<String>>(&mut self, name: S)
pub fn set_draw_mime_type<S: Into<String>>(&mut self, name: S)
The draw:mime-type attribute specifies the MIME type of the media type that a plugin processes, or the MIME type of the image given by a draw:image element. Valid values for this attribute are those defined in accordance with 3.7 of [RFC2616], or registered in accordance with [RFC6838]. Note: Additional information on MIME media types can be found at [MIMETYPES].
sourcepub fn set_xlink_actuate(&mut self, actuate: XLinkActuate)
pub fn set_xlink_actuate(&mut self, actuate: XLinkActuate)
See 5.6.2 of [XLink].
sourcepub fn set_xlink_href<S: Into<String>>(&mut self, href: S)
pub fn set_xlink_href<S: Into<String>>(&mut self, href: S)
The xlink:href 19.916 attribute specifies a remote resource. Its data type is anyIRI. See 5.4 of [XLink].
sourcepub fn set_xlink_show(&mut self, show: XLinkShow)
pub fn set_xlink_show(&mut self, show: XLinkShow)
See 5.6.1 of [XLink].
sourcepub fn set_xlink_type(&mut self, ty: XLinkType)
pub fn set_xlink_type(&mut self, ty: XLinkType)
See 3.2 of [XLink]. This attribute always has the value ‘simple’ in OpenDocument document instances.
sourcepub fn set_xml_id<S: Into<String>>(&mut self, id: S)
pub fn set_xml_id<S: Into<String>>(&mut self, id: S)
The table:end-y attribute specifies the y-coordinate of the end position of a shape relative to the top-left edge of a cell. The size attributes of the shape are ignored.