FontFaceDecl

Struct FontFaceDecl 

pub struct FontFaceDecl { /* private fields */ }
The style:font-face element represents a font face declaration which documents the properties of a font used in a document.

OpenDocument font face declarations directly correspond to the @font-face font description of CSS2 (see 15.3.1) and the font-face element of SVG (see 20.8.3).

OpenDocument font face declarations may have an unique name. This name can be used inside styles (as an attribute of style:text-properties element) as value of the style:fontname attribute to select a font face declaration. If a font face declaration is referenced by name, the font-matching algorithms for selecting a font declaration based on the font-family, font-style, font-variant, font-weight and font-size descriptors are not used but the referenced font face declaration is used directly. (See 15.5 CSS2)

Consumers should implement the CSS2 font-matching algorithm with the OpenDocument font face extensions. They may implement variations of the CSS2 font-matching algorithm. They may implement a font-matching based only on the font face declarations, that is, a font-matching that is not applied to every character independently but only once for each font face declaration. (See 15.5 CSS2)

Font face declarations support the font descriptor attributes and elements described in 20.8.3 of SVG.

Implementations

Source

impl FontFaceDecl

pub fn new_empty() -> Self

New, empty.

pub fn new<S: AsRef<str>>(name: S) -> Self

New, with a name.

pub fn new_with_name<S: AsRef<str>>(name: S) -> Self

👎Deprecated

New with a name.

pub fn set_name<V: AsRef<str>>(&mut self, name: V)

Set the name.

pub fn name(&self) -> &String

Returns the name.

pub fn set_origin(&mut self, origin: StyleOrigin)

Origin of the style

pub fn origin(&self) -> StyleOrigin

Origin of the style

pub fn attrmap(&self) -> &AttrMap2

General attributes.

pub fn attrmap_mut(&mut self) -> &mut AttrMap2

General attributes.

pub fn set_font_family_generic(&mut self, font: FontFamilyGeneric)

The style:font-family-generic attribute specifies a generic font family name.

The defined values for the style:font-family-generic attribute are:

  • decorative: the family of decorative fonts.
  • modern: the family of modern fonts.
  • roman: the family roman fonts (with serifs).
  • script: the family of script fonts.
  • swiss: the family roman fonts (without serifs).
  • system: the family system fonts.
pub fn set_font_pitch(&mut self, pitch: FontPitch)

The style:font-pitch attribute specifies whether a font has a fixed or variable width.

The defined values for the style:font-pitch attribute are:

  • fixed: font has a fixed width.
  • variable: font has a variable width.
pub fn set_font_family<S: Into<String>>(&mut self, name: S)

External font family name.

pub fn set_font_stretch(&mut self, stretch: FontStretch)

External font stretch value.

pub fn set_font_style(&mut self, style: FontStyle)

External font style value.

pub fn set_font_variant(&mut self, variant: FontVariant)

External font variant.

pub fn set_font_weight(&mut self, weight: FontWeight)

External font weight.