pub struct HeaderFooter { /* private fields */ }Expand description
Header/Footer data. Can be seen as three regions left/center/right or as one region. In the first case region* contains the data, in the second it’s content. Each is a TextTag of parsed XML-tags.
Implementations
Sourcepub fn set_display(&mut self, display: bool)
pub fn set_display(&mut self, display: bool)
Is the header displayed. Used to deactivate left side headers.
Sourcepub fn set_left(&mut self, txt: Vec<TextTag>)
pub fn set_left(&mut self, txt: Vec<TextTag>)
Set the content of the left region of the header.
Attention: This tag must be a text:p otherwise its ignored.
Sourcepub fn add_left(&mut self, txt: TextTag)
pub fn add_left(&mut self, txt: TextTag)
Adds to the content of the left region of the header.
Attention: This tag must be a text:p otherwise its ignored.
Sourcepub fn clear_left(&mut self)
pub fn clear_left(&mut self)
Clear left region.
Sourcepub fn set_center(&mut self, txt: Vec<TextTag>)
pub fn set_center(&mut self, txt: Vec<TextTag>)
Set the content of the center region of the header.
Attention: This tag must be a text:p otherwise its ignored.
Sourcepub fn add_center(&mut self, txt: TextTag)
pub fn add_center(&mut self, txt: TextTag)
Adds to the content of the center region of the header.
Attention: This tag must be a text:p otherwise its ignored.
Sourcepub fn clear_center(&mut self)
pub fn clear_center(&mut self)
Center region.
Sourcepub fn center_mut(&mut self) -> &mut Vec<TextTag> ⓘ
pub fn center_mut(&mut self) -> &mut Vec<TextTag> ⓘ
Center region.
Sourcepub fn set_right(&mut self, txt: Vec<TextTag>)
pub fn set_right(&mut self, txt: Vec<TextTag>)
Set the content of the right region of the header.
Attention: This tag must be a text:p otherwise its ignored.
Sourcepub fn add_right(&mut self, txt: TextTag)
pub fn add_right(&mut self, txt: TextTag)
Adds to the content of the right region of the header.
Attention: This tag must be a text:p otherwise its ignored.
Sourcepub fn clear_right(&mut self)
pub fn clear_right(&mut self)
Right region.
Sourcepub fn set_content(&mut self, txt: Vec<TextTag>)
pub fn set_content(&mut self, txt: Vec<TextTag>)
Header content, if there are no regions.
Sourcepub fn add_content(&mut self, txt: TextTag)
pub fn add_content(&mut self, txt: TextTag)
Adds header content, if there are no regions.
Sourcepub fn content_mut(&mut self) -> &mut Vec<TextTag> ⓘ
pub fn content_mut(&mut self) -> &mut Vec<TextTag> ⓘ
Header content, if there are no regions.