pub struct HeaderFooterStyle { /* private fields */ }Expand description
Style attributes for header/footer.
Implementations
Sourcepub fn set_background_color(&mut self, color: Rgb<u8>)
pub fn set_background_color(&mut self, color: Rgb<u8>)
The fo:background-color attribute specifies a background color for characters, paragraphs, text sections, frames, page bodies, headers, footers, table cells, table rows and tables. This can be transparent or a color. If the value is set to transparent, it switches off any background image that is specified by a style:background-image 17.3.
If a value for a draw:fill attribute is provided in a style, any background image that is specified by a style:background-image element and any background color that is specified with the fo:background-color attribute are switched off.
Sourcepub fn set_border(&mut self, width: Length, border: Border, color: Rgb<u8>)
pub fn set_border(&mut self, width: Length, border: Border, color: Rgb<u8>)
Border style all four sides. See 7.29.3 of XSL.
Sourcepub fn set_border_bottom(
&mut self,
width: Length,
border: Border,
color: Rgb<u8>,
)
pub fn set_border_bottom( &mut self, width: Length, border: Border, color: Rgb<u8>, )
Border style. See 7.29.4 of XSL
Sourcepub fn set_border_left(&mut self, width: Length, border: Border, color: Rgb<u8>)
pub fn set_border_left(&mut self, width: Length, border: Border, color: Rgb<u8>)
Border style. See 7.29.6 of XSL.
Sourcepub fn set_border_right(
&mut self,
width: Length,
border: Border,
color: Rgb<u8>,
)
pub fn set_border_right( &mut self, width: Length, border: Border, color: Rgb<u8>, )
Border style. See 7.29.7 of XSL.
Sourcepub fn set_border_top(&mut self, width: Length, border: Border, color: Rgb<u8>)
pub fn set_border_top(&mut self, width: Length, border: Border, color: Rgb<u8>)
Border style. See 7.29.10 of XSL.
Sourcepub fn set_margin(&mut self, margin: Margin)
pub fn set_margin(&mut self, margin: Margin)
See 7.29.14 of XSL. In the OpenDocument XSL-compatible namespace, the fo:margin attribute does not support auto and inherit values.
The fo:margin attribute is usable with the following elements: style:graphicproperties 17.21, style:header-footer-properties 17.5, style:pagelayout-properties 17.2, style:paragraph-properties 17.6 and style:tableproperties 17.15.
Sourcepub fn set_margin_bottom(&mut self, margin: Margin)
pub fn set_margin_bottom(&mut self, margin: Margin)
See 7.10.2 of XSL. If this attribute is contained in a style:paragraph-properties 17.6 element, its value may be a percentage that refers to the corresponding margin of a parent style. In the OpenDocument XSL-compatible namespace, the fo:margin-bottom attribute does not support the auto and inherit values.
The fo:margin-bottom attribute is usable with the following elements: style:graphicproperties 17.21, style:header-footer-properties 17.5, style:pagelayout-properties 17.2, style:paragraph-properties 17.6 and style:tableproperties 17.15.
Sourcepub fn set_margin_left(&mut self, margin: Margin)
pub fn set_margin_left(&mut self, margin: Margin)
See 7.10.3 of XSL. If this attribute is contained in a style:paragraph-properties 17.6 element, its value may be a percentage that refers to the corresponding margin of a parent style. Tables that align to the left or to the center ignore right margins, and tables that align to the right or to the center ignore left margins.
The fo:margin-left attribute is usable with the following elements: style:graphicproperties 17.21, style:header-footer-properties 17.5, style:pagelayout-properties 17.2, style:paragraph-properties 17.6, style:sectionproperties 17.11 and style:table-properties 17.15.
Sourcepub fn set_margin_right(&mut self, margin: Margin)
pub fn set_margin_right(&mut self, margin: Margin)
See 7.10.4 of XSL. If this attribute is contained in a style:paragraph-properties 17.6 element, its value may be a percentage that refers to the corresponding margin of a parent style. Tables that align to the left or to the center ignore right margins, and tables that align to the right or to the center ignore left margins.
The fo:margin-right attribute is usable with the following elements: style:graphicproperties 17.21, style:header-footer-properties 17.5, style:pagelayout-properties 17.2, style:paragraph-properties 17.6, style:sectionproperties 17.11 and style:table-properties 17.15.
Sourcepub fn set_margin_top(&mut self, margin: Margin)
pub fn set_margin_top(&mut self, margin: Margin)
See 7.10.1 of XSL. If this attribute is contained in a style:paragraph-properties 17.6 element, its value may be a percentage that refers to the corresponding margin of a parent style. In the OpenDocument XSL-compatible namespace, the fo:margin-top attribute does not support the inherit value.
The fo:margin-top attribute is usable with the following elements: style:graphicproperties 17.21, style:header-footer-properties 17.5, style:pagelayout-properties 17.2, style:paragraph-properties 17.6 and style:tableproperties 17.15.
Sourcepub fn set_min_height(&mut self, height: LengthPercent)
pub fn set_min_height(&mut self, height: LengthPercent)
Minimum height.
Sourcepub fn set_padding(&mut self, padding: Length)
pub fn set_padding(&mut self, padding: Length)
Padding for all sides. See 7.29.15 of XSL.
The fo:padding attribute is usable with the following elements: style:graphicproperties 17.21, style:header-footer-properties 17.5, style:pagelayout-properties 17.2, style:paragraph-properties 17.6 and style:tablecell-properties 17.18.
Sourcepub fn set_padding_bottom(&mut self, padding: Length)
pub fn set_padding_bottom(&mut self, padding: Length)
Padding. See 7.7.36 of XSL.
The fo:padding-bottom attribute is usable with the following elements: style:graphicproperties 17.21, style:header-footer-properties 17.5, style:pagelayout-properties 17.2, style:paragraph-properties 17.6 and style:tablecell-properties 17.18.
Sourcepub fn set_padding_left(&mut self, padding: Length)
pub fn set_padding_left(&mut self, padding: Length)
Padding. See 7.7.37 of XSL.
The fo:padding-left attribute is usable with the following elements: style:graphicproperties 17.21, style:header-footer-properties 17.5, style:pagelayout-properties 17.2, style:paragraph-properties 17.6 and style:tablecell-properties 17.18.
Sourcepub fn set_padding_right(&mut self, padding: Length)
pub fn set_padding_right(&mut self, padding: Length)
Padding. See 7.7.38 of XSL.
The fo:padding-right attribute is usable with the following elements: style:graphicproperties 17.21, style:header-footer-properties 17.5, style:pagelayout-properties 17.2, style:paragraph-properties 17.6 and style:tablecell-properties 17.18.
Sourcepub fn set_padding_top(&mut self, padding: Length)
pub fn set_padding_top(&mut self, padding: Length)
Padding. See 7.7.35 of XSL.
The fo:padding-top attribute is usable with the following elements: style:graphicproperties 17.21, style:header-footer-properties 17.5, style:pagelayout-properties 17.2, style:paragraph-properties 17.6 and style:tablecell-properties 17.18.
Sourcepub fn set_border_line_width(
&mut self,
inner: Length,
spacing: Length,
outer: Length,
)
pub fn set_border_line_width( &mut self, inner: Length, spacing: Length, outer: Length, )
The style:border-line-width attribute specifies the widths of borders defined by the FO border properties (see 20.183) for borders where the value of these properties is double. The value of the style:border-line-width attribute is a list of three white space-separated lengths, as follows:
- The first value specifies the width of the inner line
- The second value specifies the distance between the two lines
- The third value specifies the width of the outer line
The style:border-line-width attribute is usable with the following elements: style:graphic-properties 17.21, style:header-footer-properties 17.5, style:page-layout-properties 17.2, style:paragraph-properties 17.6 and style:table-cell-properties 17.18.
Sourcepub fn set_border_line_width_bottom(
&mut self,
inner: Length,
spacing: Length,
outer: Length,
)
pub fn set_border_line_width_bottom( &mut self, inner: Length, spacing: Length, outer: Length, )
The style:border-line-width-bottom attribute specifies the widths of the bottom border for borders defined by the FO border properties (see 20.183) if the property for the bottom border has the value double. The value of the style:border-line-width-bottom attribute is a list of three white spaceseparated lengths, as follows:
- The first value specifies the width of the inner line
- The second value specifies the distance between the two lines
- The third value specifies the width of the outer line
The style:border-line-width attribute is usable with the following elements: style:graphic-properties 17.21, style:header-footer-properties 17.5, style:page-layout-properties 17.2, style:paragraph-properties 17.6 and style:table-cell-properties 17.18.
Sourcepub fn set_border_line_width_left(
&mut self,
inner: Length,
spacing: Length,
outer: Length,
)
pub fn set_border_line_width_left( &mut self, inner: Length, spacing: Length, outer: Length, )
The style:border-line-width-left attribute specifies the widths of the left border for borders defined by the FO border properties (see 20.183) if the property for the left border has the value double. The value of the style:border-line-width-left attribute is a list of three white spaceseparated lengths, as follows:
- The first value specifies the width of the inner line
- The second value specified the distance between the two lines
- The third value specifies the width of the outer line
The style:border-line-width attribute is usable with the following elements: style:graphic-properties 17.21, style:header-footer-properties 17.5, style:page-layout-properties 17.2, style:paragraph-properties 17.6 and style:table-cell-properties 17.18.
Sourcepub fn set_border_line_width_right(
&mut self,
inner: Length,
spacing: Length,
outer: Length,
)
pub fn set_border_line_width_right( &mut self, inner: Length, spacing: Length, outer: Length, )
The style:border-line-width-right attribute specifies the widths of the right border for borders defined by the FO border properties (see 20.183) if the property for the right border has the value double. The value of the style:border-line-width-right attribute is a list of three white spaceseparated lengths, as follows:
- The first value specifies the width of the inner line
- The second value specified the distance between the two lines
- The third value specifies the width of the outer line
The style:border-line-width attribute is usable with the following elements: style:graphic-properties 17.21, style:header-footer-properties 17.5, style:page-layout-properties 17.2, style:paragraph-properties 17.6 and style:table-cell-properties 17.18.
Sourcepub fn set_border_line_width_top(
&mut self,
inner: Length,
spacing: Length,
outer: Length,
)
pub fn set_border_line_width_top( &mut self, inner: Length, spacing: Length, outer: Length, )
The style:border-line-width-top attribute specifies the widths of the top border for borders defined by the FO border properties (see 20.183) if the property for the top border has the value double. The value of the style:border-line-width-top attribute is a list of three white spaceseparated lengths, as follows:
- The first value specifies the width of the inner line
- The second value specified the distance between the two lines
- The third value specifies the width of the outer line
The style:border-line-width attribute is usable with the following elements: style:graphic-properties 17.21, style:header-footer-properties 17.5, style:page-layout-properties 17.2, style:paragraph-properties 17.6 and style:table-cell-properties 17.18.
Sourcepub fn set_dynamic_spacing(&mut self, dynamic: bool)
pub fn set_dynamic_spacing(&mut self, dynamic: bool)
Dynamic spacing
Sourcepub fn set_shadow(
&mut self,
x_offset: Length,
y_offset: Length,
blur: Option<Length>,
color: Rgb<u8>,
)
pub fn set_shadow( &mut self, x_offset: Length, y_offset: Length, blur: Option<Length>, color: Rgb<u8>, )
The style:shadow attribute specifies a shadow effect. The defined values for this attribute are those defined in 7.16.5 of XSL, except the value inherit.
The shadow effect is not applied to the text content of an element, but depending on the element where the attribute appears, to a paragraph, a text box, a page body, a header, a footer, a table or a table cell.
The style:shadow attribute is usable with the following elements: style:graphicproperties 17.21, style:header-footer-properties 17.5, style:pagelayout-properties 17.2, style:paragraph-properties 17.6, style:tablecell-properties 17.18 and style:table-properties 17.15.
Sourcepub fn set_height(&mut self, height: Length)
pub fn set_height(&mut self, height: Length)
Height.