pub enum LineStyle {
    Dash,
    DotDash,
    DotDotDash,
    Dotted,
    LongDash,
    None,
    Solid,
    Wave,
}
Line style for underline, overline, line-through.

20.373 style:text-line-through-style 20.390 style:text-underline-style 20.381 style:text-overline-style

The style:text-underline-style attribute specifies a style for underlining text. The defined values for the style:text-underline-style attribute are:

  • none: text has no underlining.
  • dash: text has a dashed line underlining it.
  • dot-dash: text has a line whose repeating pattern is a dot followed by a dash underlining it.
  • dot-dot-dash: text has a line whose repeating pattern is two dots followed by a dash underlining it.
  • dotted: text has a dotted line underlining it.
  • long-dash: text has a dashed line whose dashes are longer than the ones from the dashed line for value dash underlining it.
  • solid: text has a solid line underlining it.
  • wave: text has a wavy line underlining it.

Note: The definitions of the values of the style:text-underline-style attribute are based on the text decoration style ‘text-underline-style’ from CSS3Text, 9.2.

The values of the style:text-underline-style attribute are none, solid, dotted, dash, long-dash, dot-dash, dot-dot-dash or wave.

Variants



Dash



DotDash



DotDotDash



Dotted



LongDash



None



Solid



Wave