Enum spreadsheet_ods::style::units::LineType
source · pub enum LineType {
None,
Single,
Double,
}Expand description
20.376 style:text-line-through-type 20.382 style:text-overline-type 20.391 style:text-underline-type
The style:text-line-through-type attribute specifies whether text is lined through, and if so, whether a single or double line will be used.
The defined values for the style:text-line-through-type attribute are: • double: a double line should be used for a line-through text. • none: deprecated. • single: a single line should be used for a line-through text.
Every occurrence of the style:text-line-through-type attribute should be accompanied by an occurrence of the style:text-line-through-style 20.373 attribute on the same element. There should not be an occurrence of the style:text-line-through-type attribute if the value of the style:text-line-through-style attribute is none.
The values of the style:text-line-through-type attribute are none, single or double.