pub enum PrintOrder {
Ltr,
Ttb,
}Expand description
20.332 style:print-page-order
The style:print-page-order attribute specifies the order in which data in a spreadsheet is numbered and printed when the data does not fit on one printed page.
The defined values for the style:print-page-order attribute are:
- ltr: create pages from the first column to the last column before continuing with the next set of rows.
- ttb: create pages from the top row to the bottom row before continuing with the next set of columns.
Variants